Struct ModelRouter
pub struct ModelRouter { /* private fields */ }Expand description
Client router for models.
Implementations
impl ModelRouter
impl ModelRouter
pub fn new(uri: &str, prefix: &str, timeout_s: f64, http: Client) -> Self
pub fn new(uri: &str, prefix: &str, timeout_s: f64, http: Client) -> Self
Creates a new model router.
pub fn post(&self, name: &str, source: &ModelSource) -> Result<String>
pub fn post(&self, name: &str, source: &ModelSource) -> Result<String>
Posts a model from a local file or a remote URL, saving it as name.
pub fn put(&self, source: &ModelSource, name: Option<&str>) -> Result<String>
pub fn put(&self, source: &ModelSource, name: Option<&str>) -> Result<String>
Puts (overwrites) a model from a local file or a remote URL.
For ModelSource::Path the filename is derived from the path. For
ModelSource::Url a name is required.